@@ -101,7 +101,8 @@ AZURE = {
     "DestinationIpInfo.DestinationIpLongitude": "destination.geolocation.longitude",
     "DestinationIpInfo.DestinationIpMetroCode": "extra.destination.geolocation.metro_code",
     "DestinationIpInfo.DestinationIpAreaCode": "extra.destination.geolocation.area_code",
-    "DestinationIpInfo.DestnationIpConnectionType": "protocol.application",
+    "DestinationIpInfo.DestinationIpConnectionType": "protocol.application",
+    "DestinationIpInfo.DestinationIpv4Int": "__IGNORE__",
     "DestinationPort": "destination.port",
     "TargetIp": "__IGNORE__",
     "TargetPort": "__IGNORE__",
